/**
 * Workplace plugin Webaccess 6.40
 */

Plugino3spaces.prototype = new Plugin;
Plugino3spaces.prototype.constructor = Plugino3spaces;
Plugino3spaces.superclass = Plugin.prototype;

function Plugino3spaces(){}

/**
 * init
 *
 * registers for events 
 */
Plugino3spaces.prototype.init = function(){
	this.registerHook("client.module.maillistmodule.contextmenu.buildup");
	this.registerHook("client.module.maillistmodule.execute.before");

	// Add HTML elements to show location where mail has been archived
	this.registerHook("client.module.previewreadmailitemmodule.item.before");
}


/**
 * PLUGIN execute
 *
 * is called when registered events are triggered 
 */
Plugino3spaces.prototype.execute = function(eventID, data){
	switch(eventID){
		case "client.module.maillistmodule.contextmenu.buildup":
			this.addWorkplacePublishContextMenu(data);
			break;
		case "client.module.maillistmodule.execute.before":
			this.mailListModuleExecute(data);
			break;
		case "client.module.previewreadmailitemmodule.item.before":
			this.onMessagePreview(data);
			break;
	}
};

/**
 * Display Workspace published location and datetime if message was uploaded.
 */
Plugino3spaces.prototype.onMessagePreview = function(data) {

	var maillistmodule = webclient.getModulesByName("maillistmodule")[0];

	var entryid = dhtml.getXMLValue( data.message, "entryid" );
	var msgProps = maillistmodule.itemProps[ entryid ];

	var WPPublishDateTime  = msgProps['o3spaces_workplace_publish_datetime'];
	var WPPublishWorkspace = msgProps['o3spaces_workplace_publish_location'];

	if (WPPublishDateTime || WPPublishWorkspace) {
		var newDate = new Date( );
		newDate.setTime( WPPublishDateTime * 1000 );
		var dateString = newDate.toLocaleString();

		var extrainfo = document.getElementById("extrainfo");
		if (extrainfo) {
			extrainfo.innerHTML = "<p>" + dgettext("plugin_o3spaces", "Published to") + " <b>" + WPPublishWorkspace + 
				"</b> " + dgettext("plugin_o3spaces", "at") + " " + dateString + "</p>";
			extrainfo.style.display = 'block';
		}
	}

	return true;
}

/**
 * Event: addWorkplacePublishContextMenu
 *
 * New entry to contextmenu on message selection to upload to workplace.
 */
Plugino3spaces.prototype.addWorkplacePublishContextMenu = function(data){
    var items = data["contextmenu"];
    items.push(webclient.menu.createMenuItem("seperator", ""));
    items.push(webclient.menu.createMenuItem("o3spaces_publish", dgettext('plugin_o3spaces', "Publish to the Workplace")+"...", dgettext('plugin_o3spaces', "Publish to the Workplace"), Plugino3spaces.prototype.eventListContextMenuWorkplacePublishSelectDialog));
}


/**
 *
 * Action handler to select workspace location to upload to.
 */
Plugino3spaces.prototype.eventListContextMenuWorkplacePublishSelectDialog = function(moduleObject, element, event) {
    element.parentNode.style.display = "none";
    // open dialog to select space
    webclient.openModalDialog(moduleObject, 'workspace', DIALOG_URL+"task=workspace&plugin=o3spaces&type=publish", 600,380, 
		workspaceBrowseDialog_publishToCallBack, {moduleObject:moduleObject, element:element, elementid:element.parentNode.elementid});
}


/**
 * Callback function when selecting a destination location to publish the messages to.
 * 
 */
function workspaceBrowseDialog_publishToCallBack(result, callbackData) {

	var data = {
		store: callbackData.moduleObject.storeid,
		parententryid: callbackData.moduleObject.entryid,
		// Destination path to publish files to
		destinationFolder: result.folder	
	};

	// Grab the IDs of the messages selected	
    var entryids = Array();

    var items = callbackData.moduleObject.getSelectedMessages(callbackData.elementid);
    for(i in items){
        entryids.push(callbackData.moduleObject.entryids[items[i]]);
    }
    data["entryids"] = entryids;

    webclient.xmlrequest.addData(callbackData.moduleObject, "WorkplacePublish", data);

    // deselect selected message
    eventListCheckSelectedContextMessage(callbackData.moduleObject);

}


/**
 * Action: mailListModuleExecute
 *
 * process incoming execute events for maillistmodule
 */
Plugino3spaces.prototype.mailListModuleExecute = function(data) {
    var type = data["type"];
    var action = data["action"];

    switch(type){
        case "WorkplacePublicationResponse":
            this.publicationResponse(action);
            break;
    }
}


/**
 * Action: publicationResponse
 *
 * Process response-message after e-mail publicatoin
 */
Plugino3spaces.prototype.publicationResponse = function(action) {

	// Report an error if needed.
	var isError = dhtml.getXMLValue(action, "isError");
	if (parseInt(isError)>0) {
		alert( dhtml.getXMLValue(action, "errorMessage", "Internal Error. Error reported, no message given") );
		return;
	}


	var archivedMessages = dhtml.getXMLValue(action, "archivedMessages", "none");
	alert(dgettext('plugin_o3spaces', "Published messages to the Workplace")+": " + archivedMessages);

	
	webclient.hierarchy.selectLastFolder(true);

}


/**
 * Callback: workspaceBrowseDialog_selectFileCallBack
 *
 * Attach a file from the Workplace to the message
 */
function workspaceBrowseDialog_selectFileCallBack (result, callbackData) {
	dhtml.getElementById('workspace_location').value = result.folder;

    // submit upload form
    dhtml.getElementById('upload').submit();
}
