/**
 * O3Spaces Browser code
 */
workspacemodule.prototype = new Module;
workspacemodule.prototype.constructor = workspacemodule;
workspacemodule.superclass = Module.prototype;


/**
 * Constructor 
 */ 
function workspacemodule(id, element, title, data) {
    if(arguments.length > 0) {
        this.init(id, element, title, data);
    }
    this.viewFiles = false;    
    this.targetUrl = '';
	this.rootPath = "mail";
	this.mode = "";
}


/**
 * Initialization
 */ 
workspacemodule.prototype.init = function(id, element, title, data) {
    workspacemodule.superclass.init.call(this, id, element, title, data);
}


/**
 * Setter if in filebrowser or spacebroser
 *
 * @param boolean viewFiles
 */ 
workspacemodule.prototype.setFilesView = function(viewFiles) {
    this.viewFiles = viewFiles;
}

/**
 * Set root folder. set to "mail" to retrieve Mail rootfolders 
 */
workspacemodule.prototype.setRootFolder = function(root) {
	this.rootFolder = root;
}

/**
 * Set mode, e.g. "insert" or "publish"
 */
workspacemodule.prototype.setMode = function(mode) {
	this.mode = mode;
}

/**
 * Loads the nodes for the browser
 */
workspacemodule.prototype.loadData = function(restoreState) {
    webclient.xmlrequest.addData(this, "queryDirectoryTree", {
		viewFiles:    this.viewFiles,    // return file entries or only directories?
		folder:       this.rootFolder,   // folder to query contents from
		restoreState: restoreState,      // include data up-to the path stored in the session?
		mode:         this.mode          // dialog's mode running in (insert/publish)
	});

    webclient.xmlrequest.sendRequest();
}


/** Query the contents of a O3Spaces folder */
workspacemodule.prototype.selectFolder = function( parentId, folder, nodeLabel, fetchFromServer ) {

	// Store what was clicked
	window.tmpResultData = {
		parentId: parentId,
		folder: folder
	};

	// Create awareness
	var dest = document.getElementById("selectedInfo");
	if (dest) {
		var text = dgettext('plugin_o3spaces', 'Publish to:');
		if (this.viewFiles)
			text = dgettext('plugin_o3spaces', 'Insert file:');
		dest.innerHTML = "<nobr>" + text + ' ' + nodeLabel + "</nobr>";
	}

	if (fetchFromServer) {
		webclient.xmlrequest.addData(this, "queryDirectoryTree", { 'viewFiles': this.viewFiles, 'folder': folder, 'parentId': parentId });
		webclient.xmlrequest.sendRequest();
	}


}

workspacemodule.prototype.okClick = function() {
	window.resultCallBack( window.tmpResultData, window.callBackData );
	window.close();
}


/**
 * Function which execute an action. This function is called by the XMLRequest object.
 *
 * @param string type the action type
 * @param object action the action tag 
 */ 
workspacemodule.prototype.execute = function(type, action) {
	//console.log('workspacemodule.prototype.execute type='+type + ' action='+action);
    switch(type) {
        case "listspaces":
            this.listSpaces(action);
            break;
    }
}

/**
 * executed when the server is sending data for the browser
 * existing nodes are deleted (ex. loading node) and received nodes are displayed
 *
 * @param mixed action
 */
workspacemodule.prototype.listSpaces = function(action) {
    var spaceDiv = document.getElementById("spacesTree");

	if (parseInt(dhtml.getXMLValue(action, "error")) > 0 )
	{
		var msg = dhtml.getXMLValue(action, "errorMessage", "Internal Error while retrieving spaces. No message given.");
		alTree.hideLoadingNode();

		alTree.addRecord({
			space_id: 1,
			parent_id: 0,
			display_name: msg,
			title: msg,
			size: 0,
			isdocument: false,
			icon: "../icon_close",
			url: null
		});

		spaceDiv.innerHTML = alTree;
		
		return;
	}

	var parentId = null;

	var initialized = false; // not yet ready

    if (alTree && spaceDiv) {
		// remove the "loading" node
		alTree.hideLoadingNode();

		alTree.config.onToggleEvent = function(node) {
			if (initialized){
				module.selectFolder( node.id, node.payload, node.name, false );
			}
		}

		var imguri = dhtml.getXMLValue(action, "imguri", "none");

		// loop through values from server
		var spaces = action.getElementsByTagName("spaces");

		for(var i=0;i<spaces.length;i++){
			var space = spaces[i];
			var data = {
				id: dhtml.getXMLValue(space, "id"),
				parentId: dhtml.getXMLValue(space, "parentId"),
				name: dhtml.getXMLValue(space, "name"),
				webdav_path: dhtml.getXMLValue(space, "webdav_path"),
				url: null,
				size: this.convertSize(dhtml.getXMLValue(space, "size")),
				isdocument: dhtml.getXMLValue(space, "isdocument"),
				icon: dhtml.getXMLValue(space, "icon"),
				icon_open: dhtml.getXMLValue(space, "icon_open")
			}

			// build a clickable Spaces only when not in fileview
			//if (data.full_path && (this.viewFiles || data.isdocument))  
			//data.url = "javascript:module.selectFolder('"+ data.id + "', '"+encodeURIComponent(data.webdav_path)+"', '"+ data.name +"');"; // ???
			data.url = "javascript:module.selectFolder('"+ data.id + "', '"+encodeURIComponent(data.webdav_path)+"', '"+ data.name +"', true);"; // ???
			if (! data.isdocument) 
				data.size = null;

			if (data.icon) data.icon = imguri+'img/filetypes/' + data.icon +'.gif';
			if (data.icon_open) data.icon_open = imguri+'img/filetypes/' + data.icon_open +'.gif';

			// add the node to the tree
			alTree.add(
				data.id, 
				data.parentId, 
				data.name, // display_name
				data.url, 
				data.name,  // title
				null, 
				data.icon, 
				data.icon_open ? data.icon_open : null,
				null,
				data.size, 
				data.isdocument,
				data.webdav_path // payload
			);

		}

		if (window.tmpResultData && window.tmpResultData.parentId) {
			alTree.openTo(window.tmpResultData.parentId,false,false);
		}

		initialized = true;
		spaceDiv.innerHTML = alTree;
	}
}

/**
 * converts a size in bytes to a KB/MB/GB/TB string
 *
 * @param integer size in bytes
 * @return string 
 */
workspacemodule.prototype.convertSize = function(size) {
    if (! size) return null;
    
    var nsize = size;
    var type = "B";

    while (nsize > 1023) {
        nsize = nsize / 1024;

        if (type == 'B') { type = 'KB'; }
        else if (type == 'KB') { type = 'MB'; }
        else if (type == 'MB') { type = 'GB'; }
        else if (type == 'GB') { type = 'TB'; break;}
    }
    var str = Math.round(nsize*10)/10+' '+type;
    if (type.length == 1) str += '&nbsp;&nbsp;';
    return str;
}

